@@ -20,6 +20,7 @@
 
 #include "fileformatmanager.h"
 #include "fileformatinterface.h"
+#include "logging_p.h"
 
 #include <KPluginLoader>
 #include <KPluginMetaData>
@@ -29,19 +30,16 @@
 #include <QDirIterator>
 #include <QJsonArray>
 #include <QJsonObject>
-#include <QLoggingCategory>
 
 using namespace GraphTheory;
 
-Q_LOGGING_CATEGORY(FILEFORMAT, "rocs.graphtheory.fileformat")
-
 class GraphTheory::FileFormatManagerPrivate
 {
 public:
     FileFormatManagerPrivate()
-        : defaultGraphFilePlugin(0)
+        : defaultGraphFilePlugin(nullptr)
     {
-        QLoggingCategory::setFilterRules(QStringLiteral("rocs.graphtheory.fileformat.debug=false"));
+
     }
 
     ~FileFormatManagerPrivate()
@@ -115,9 +113,9 @@ void FileFormatManager::loadBackends()
         });
         for (const auto &metadata : metadataList) {
             loader.setFileName(metadata.fileName());
-            qCDebug(FILEFORMAT) << "Load Plugin: " << metadata.name();
+            qCDebug(GRAPHTHEORY_FILEFORMAT) << "Load Plugin: " << metadata.name();
             if (!loader.load()) {
-                qCCritical(FILEFORMAT) << "Error while loading plugin: " << metadata.name();
+                qCCritical(GRAPHTHEORY_FILEFORMAT) << "Error while loading plugin: " << metadata.name();
             }
             KPluginFactory *factory = KPluginLoader(loader.fileName()).factory();
             FileFormatInterface *plugin = factory->create<FileFormatInterface>(this);
@@ -132,12 +130,16 @@ void FileFormatManager::loadBackends()
 FileFormatInterface * FileFormatManager::backendByExtension(const QString &ext)
 {
     QString suffix = ext.section('.', -1); // get suffix
+    if (suffix.isEmpty()) {
+        qCWarning(GRAPHTHEORY_FILEFORMAT) << "File does not contain extension, falling back to default file format";
+        return defaultBackend();
+    }
     foreach(FileFormatInterface * p,  d->backends) {
         if (p->extensions().join(";").contains(suffix, Qt::CaseInsensitive)) {
             return p;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 FileFormatInterface * FileFormatManager::defaultBackend()
